@@ -1,7 +1,9 @@
+from typing import Optional
+
 from .base import *
 
 
-_default_context = None
+_default_context: Optional[BaseContext] = None
 
 
 def set_default_context(context: BaseContext):
@@ -9,7 +11,7 @@ def set_default_context(context: BaseContext):
     _default_context = context
 
 
-def get_default_context():
+def get_default_context() -> BaseContext:
     global _default_context
 
     if _default_context is None:
